@@ -2,7 +2,7 @@ from airflow.hooks.postgres_hook import PostgresHook
 from airflow.models.baseoperator import BaseOperator
 from airflow.utils.decorators import apply_defaults
 
-from dbnd._core.commands.metrics import log_pg_table
+from dbnd._core.tracking.metrics import log_pg_table
 
 
 class LogPostgresTableOperator(BaseOperator):
